diff --git a/htdocs/comm/action/card.php b/htdocs/comm/action/card.php
index d38270b8827..c917925e87e 100644
--- a/htdocs/comm/action/card.php
+++ b/htdocs/comm/action/card.php
@@ -795,7 +795,7 @@ if ($action == 'create')
}
print '';
}
- if(!empty($origin) && !empty($originid))
+ if (!empty($origin) && !empty($originid))
{
include_once DOL_DOCUMENT_ROOT.'/core/lib/functions2.lib.php';
print '
| '.$langs->trans("LinkedObject").' | ';
diff --git a/htdocs/core/class/html.formactions.class.php b/htdocs/core/class/html.formactions.class.php
index 0654caaa51a..16b63c16601 100644
--- a/htdocs/core/class/html.formactions.class.php
+++ b/htdocs/core/class/html.formactions.class.php
@@ -180,7 +180,10 @@ class FormActions
elseif ($typeelement == 'fichinter') $title=$langs->trans('ActionsOnFicheInter');
else $title=$langs->trans("Actions");
- print load_fiche_titre($title,'','');
+ $buttontoaddnewevent = '';
+ $buttontoaddnewevent.= $langs->trans("AddEvent");
+ $buttontoaddnewevent.= '';
+ print load_fiche_titre($title, $buttontoaddnewevent, '');
$page=0; $param=''; $sortfield='a.datep';
diff --git a/htdocs/core/lib/functions.lib.php b/htdocs/core/lib/functions.lib.php
index b71c3ac0906..b1a9c0b2735 100644
--- a/htdocs/core/lib/functions.lib.php
+++ b/htdocs/core/lib/functions.lib.php
@@ -3098,7 +3098,7 @@ function print_fiche_titre($title, $mesg='', $picto='title_generic.png', $pictoi
* Load a title with picto
*
* @param string $titre Title to show
* @param string $mesg Added message to show on right
* @param string $picto Icon to use before title (should be a 32x32 transparent png file)
* @param int $pictoisfullpath 1=Icon name is a full absolute url of image
* @param int $id To force an id on html objects
@@ -3106,7 +3106,7 @@ function print_fiche_titre($title, $mesg='', $picto='title_generic.png', $pictoi
* @return string
* @see print_barre_liste
*/
-function load_fiche_titre($titre, $mesg='', $picto='title_generic.png', $pictoisfullpath=0, $id=0, $morecssontable='')
+function load_fiche_titre($titre, $morehtmlright='', $picto='title_generic.png', $pictoisfullpath=0, $id=0, $morecssontable='')
{
global $conf;
@@ -3121,9 +3121,9 @@ function load_fiche_titre($titre, $mesg='', $picto='title_generic.png', $pictois
$return.= '';
$return.= ' '.$titre.' ';
$return.= ' | ';
- if (dol_strlen($mesg))
+ if (dol_strlen($morehtmlright))
{
- $return.= ''.$mesg.' | ';
+ $return.= ''.$morehtmlright.' | ';
}
$return.= '
'."\n";
@@ -3098,7 +3098,7 @@ function print_fiche_titre($title, $mesg='', $picto='title_generic.png', $pictoi
*
* @param string $titre Title to show
- * @param string $mesg Added message to show on right
+ * @param string $morehtmlright Added message to show on right
* @param string $picto Icon to use before title (should be a 32x32 transparent png file)
* @param int $pictoisfullpath 1=Icon name is a full absolute url of image